@@ -1,8 +1,6 @@
 //! Definitions for command line argument mapping and dispatching.
 
-use std::iter::FromIterator;
-
-use clap::{self, AppSettings, Clap};
+use clap::{self, AppSettings, Parser};
 use itertools::Itertools;
 use tap::prelude::*;
 use tokio::task;
@@ -16,11 +14,11 @@ use crate::{
 };
 
 /// The command line options to be collected.
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 #[clap(
     version = clap::crate_version!(),
     author = clap::crate_authors!(),
-    global_setting = AppSettings::ColoredHelp,
+    about = clap::crate_description!(),
     setting = AppSettings::SubcommandRequiredElseHelp,
 )]
 #[allow(clippy::struct_excessive_bools)]
@@ -70,7 +68,7 @@ pub struct Pacaptr {
 }
 
 // For details on operations, flags and flagcounters, see: https://www.archlinux.org/pacman/pacman.8.html
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 #[clap(about = clap::crate_description!())]
 enum Operations {
     /// Query the package database.
@@ -212,14 +210,16 @@ impl Pacaptr {
     /// detected.
     ///
     /// # Errors
-    /// See [`Error`](crate::error::Error) for a  list of possible errors.
+    /// See [`Error`](crate::error::Error) for a list of possible errors.
     #[allow(trivial_numeric_casts)]
     async fn dispatch_from(&self, mut cfg: Config) -> Result<()> {
-        // Collect options as a `String`, eg. `-S -y -u => "Suy"`.
-        // ! HACK: In `Pm` we ensure the Pacman methods are all named with flags in
-        // ! ASCII order, ! eg. `Suy` instead of `Syu`.
-        // ! Then, in order to stay coherent with Rust coding style the method name
-        // ! should be `suy`.
+        /// Collect options as a `String`, eg. `-S -y -u => "Suy"`.
+        ///
+        /// # Hack
+        /// In `Pm` we ensure the Pacman methods are all named with flags in
+        /// ASCII order, eg. `Suy` instead of `Syu`. Then, in order to
+        /// stay coherent with Rust coding style the method name should be
+        /// `suy`.
         macro_rules! collect_options {(
             $( $op:ident {
                 $( mappings: [$( $key:ident -> $val:ident ), *], )?
@@ -263,16 +263,17 @@ impl Pacaptr {
 
         let pm = cfg.conv::<Box<dyn Pm>>();
 
-        let kws = self.keywords.iter().map(|s| s as &str).collect_vec();
-        let flags = self.extra_flags.iter().map(|s| s as &str).collect_vec();
+        let kws = self.keywords.iter().map(|s| s as _).collect_vec();
+        let flags = self.extra_flags.iter().map(|s| s as _).collect_vec();
 
-        // Call the method indicated by `options` on `pm`. That is:
-        // ```rust
-        // match &options.to_lowercase() as _ {
-        //     "q" => pm.q(&kws, &flags).await,
-        //     ..
-        // }
-        // ```
+        /// Call the method indicated by `options` on `pm`. That is:
+        ///
+        /// ```rust
+        /// match &options.to_lowercase() as _ {
+        ///     "q" => pm.q(&kws, &flags).await,
+        ///     ..
+        /// }
+        /// ```
         macro_rules! dispatch_match {(
             methods = [{ $(
                 $( #[$meta:meta] )*
@@ -299,7 +300,7 @@ impl Pacaptr {
     /// detected [`Config`].
     ///
     /// # Errors
-    /// See [`Error`](crate::error::Error) for a  list of possible errors.
+    /// See [`Error`](crate::error::Error) for a list of possible errors.
     #[allow(trivial_numeric_casts)]
     pub async fn dispatch(&self) -> Result<()> {
         let dotfile = task::block_in_place(Config::try_load);
