@@ -181,11 +181,10 @@ impl Cmd {
 ///
 /// * `src` - The input stream to read from.
 /// * `out` - The optional output stream to write to.
-async fn exec_tee<S, O>(src: &mut S, out: Option<O>) -> Result<Vec<u8>>
-where
-    S: Stream<Item = io::Result<Bytes>> + Unpin,
-    O: AsyncWrite + Unpin,
-{
+async fn exec_tee(
+    src: impl Stream<Item = io::Result<Bytes>>,
+    out: Option<impl AsyncWrite>,
+) -> Result<Vec<u8>> {
     let mut buf = Vec::<u8>::new();
     let buf_sink = (&mut buf).into_sink();
 
@@ -421,7 +420,7 @@ fn grep<'t>(text: &'t str, patterns: &[&str]) -> Result<Vec<&'t str>> {
         .iter()
         .map(|&pat| {
             Regex::new(pat)
-                .map_err(|_e| Error::OtherError(format!("Pattern `{}` is ill-formed", pat)))
+                .map_err(|_e| Error::OtherError(format!("Pattern `{pat}` is ill-formed")))
         })
         .try_collect()?;
     Ok(text
@@ -433,7 +432,7 @@ fn grep<'t>(text: &'t str, patterns: &[&str]) -> Result<Vec<&'t str>> {
 /// Prints the result of [`grep`] line by line.
 #[doc = docs_errors_grep!()]
 pub(crate) fn grep_print(text: &str, patterns: &[&str]) -> Result<()> {
-    grep(text, patterns).map(|lns| lns.iter().for_each(|ln| println!("{}", ln)))
+    grep(text, patterns).map(|lns| lns.iter().for_each(|ln| println!("{ln}")))
 }
 
 /// Checks if an executable exists by name (consult `$PATH`) or by path.
