@@ -4,7 +4,7 @@ use async_trait::async_trait;
 use indoc::indoc;
 
 use super::Pm;
-use crate::{dispatch::config::Config, exec::StatusCode};
+use crate::dispatch::Config;
 
 macro_rules! docs_self {
     () => {
@@ -16,7 +16,7 @@ macro_rules! docs_self {
 
 #[doc = docs_self!()]
 #[derive(Debug)]
-pub struct Unknown {
+pub(crate) struct Unknown {
     name: String,
     cfg: Config,
 }
@@ -24,7 +24,7 @@ pub struct Unknown {
 impl Unknown {
     #[must_use]
     /// Creates a new [`Unknown`] package manager with the given name.
-    pub fn new(name: &str) -> Self {
+    pub(crate) fn new(name: &str) -> Self {
         Unknown {
             name: format!("unknown package manager: {}", name),
             cfg: Config::default(),
@@ -42,10 +42,4 @@ impl Pm for Unknown {
     fn cfg(&self) -> &Config {
         &self.cfg
     }
-
-    async fn code(&self) -> StatusCode {
-        0
-    }
-
-    async fn set_code(&self, _to: StatusCode) {}
 }
